def save_file():
    pass


def save_json():
    pass


def _write_file(data, path, mode="w", encoding="utf-8", start="", end=""):
    """_write_file: data를 파일로 저장
    Desc:
        - 파일 확장자(json/csv/xlsx/...)별 자동 저장

    Args:
        - data(str|dict|list|dataframe): 저장할 data
        - path(str): 저장할 파일 경로(파일명 포함)
        - encoding(str, "utf-8"): 인코딩: utf-8|cp949|euc-kr

    Usages:
        - _write_file([{'a': 'b'}, 5], "./folder1/fname2.ext", encoding="utf-8")
    """
    ext = Path(path).suffix
    if "@" in path:  # NOTE!!: path = "<sheet_name>@<file_path>"
        (sheet_name, path) = path.split("@", 1)

    folder = os.path.dirname(path)
    if folder:
        os.makedirs(folder, exist_ok=True)

    if ext == ".json":
        json.dump(
            data, open(path, mode, encoding=encoding), ensure_ascii=False, indent="\t"
        )
    elif ext in [".yml", ".yaml"]:
        with open(path, "w", encoding="utf-8") as file:
            yaml.dump(data, file)
    elif ext == ".csv":
        df = _to_df(data)
        if not os.path.exists(path):
            df.to_csv(path, index=False, mode="w", header=True)
        else:
            df.to_csv(path, index=False, mode="a", header=False)
    elif ext in [".xls", ".xlsx"]:
        if not os.path.exists(path):
            with pd.ExcelWriter(path, mode="w", engine="openpyxl") as writer:
                _to_df(data).to_excel(writer, sheet_name=sheet_name, index=False)
        else:
            with pd.ExcelWriter(
                path, mode="a", engine="openpyxl", if_sheet_exists="replace"
            ) as writer:
                _to_df(data).to_excel(writer, sheet_name=sheet_name, index=False)
    else:
        if mode == "wb":
            with open(path, mode) as f:
                f.write(data)
        else:
            if type(data) == dict or type(data) == list:
                data = json.dumps(data, ensure_ascii=False, indent="\t")
            with open(path, mode, encoding="utf-8") as f:
                data = start + data + end
                f.write(data)
